#
# spec file for package nmon
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011-2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nmon
Version:        16f
Release:        11.5
Summary:        Performance Monitor
License:        GPL-3.0
Group:          System/Monitoring
Url:            http://nmon.sourceforge.net/pmwiki.php
Source0:        http://sourceforge.net/projects/nmon/files/lmon%{version}.c
Source1:        https://www.gnu.org/licenses/gpl-3.0.txt
BuildRequires:  help2man
BuildRequires:  ncurses-devel
Provides:       lmon = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This systems administrator, tuner, benchmark tool gives you a huge amount of
important performance information in one go. It can output the data in two ways

1. On screen (console, telnet, VNC, putty or X Windows) using curses for low
   CPU impact which is updated once every two seconds. You hit single characters
   on you keyboard to enable/disable the various sorts of data.
   * You can display the CPU, memory, network, disks (mini graphs or numbers),
     file systems, NFS, top processes, resources (Linux version & processors)
     and on Power micro-partition information.
2. Save the data to a comma separated file for analysis and longer term data
   capture.
   * Use this together with nmon Analyser Excel 2000 spreadsheet, which loads
     the nmon output file and automatically creates dozens of graphs ready for
     you to study or write performance reports.
   * Filter this data, add it to a rrd database (using an excellent freely
     available utility called rrdtool). This graphs the data to .gif or .png
     files plus generates the webpage .html file and you can then put the
     graphs directly on a website automatically on AIX with no need of a
     Windows based machine.
   * Directly put the data into a rrd database or other database for your own
     analysis

%prep
%setup -q -T -c %{name}-%{version}

%build
export build_cmd="-D JFS -D GETUSER -D LARGEMEM -D KERNEL_2_6_18 -Wno-unused %{SOURCE0} -o nmon -lncurses -lm -Wl,--as-needed -Wl,--no-undefined -Wl,-z,now"
%ifarch ppc ppc64 ppc64le
cc %{optflags} -D PPC \
  ${build_cmd}
%endif
%ifarch s390x
cc %{optflags} -D MAINFRAME \
  ${build_cmd}
%endif
%ifarch %arm aarch64
cc %{optflags} -D ARM \
  ${build_cmd}
%endif
%ifarch %ix86 x86_64
cc %{optflags} -D X86 \
  ${build_cmd}
%endif

%install
install -D -m 0755 nmon %{buildroot}%{_bindir}/nmon
install -d %{buildroot}%{_mandir}/man1
help2man \
  --help-option=-h \
  --no-info \
  --no-discard-stderr \
  --name="Performance Monitor" \
  --version-string=%{version} \
  ./nmon > %{buildroot}%{_mandir}/man1/nmon.1
ln -s nmon %{buildroot}%{_bindir}/lmon
ln -s nmon %{buildroot}%{_mandir}/man1/lmon.1
cp %{SOURCE1} LICENSE.GPL-3.0

%files
%defattr(-,root,root)
%doc LICENSE.GPL-3.0
%{_bindir}/nmon
%{_bindir}/lmon
%{_mandir}/man1/nmon.1%{ext_man}
%{_mandir}/man1/lmon.1%{ext_man}

%changelog
* Sat Jun 18 2016 mpluskal@suse.com
- Update to version 16f (boo#985538):
  * Minor changed to the on-screen view only.
* Fri Apr  8 2016 mpluskal@suse.com
- Update to 16e (boo#974718)
  * Boottime shown online in the Kernel "k" panel
  * Utilisation stats: /proc/stat now reports 10 Utilisation stats
    including KVM guest VM CPU use = cool.
  * Bug caused Seg Faults core dumps fixed while collecting to a
    file including top process stats.
  * Fix: Improved memory handling for extreme numbers of processes
    (1000's) or rapid exec of processes  (100's in a millisecond)
    for large Linux servers. We have examples on Intel of 80 CPU
    cores and POWER 160+
  * Online Dot "." command no longer also changes what is displayed
    as users said it was confusing.
  * Minor online start-up flash screen text changes to include C
    concise CPU stats and U for full  Utilisation stats (all 10 of
    them) instead of a file.
  * Copyright and GPL v3 notice in the code plus online "h" and
    nmon -h output
- Improve manpage generation
* Fri Mar 18 2016 mpluskal@suse.com
- Enable all features for non intel architectures
- Enable support for modern kernels
- Add symlink to lmon manpage
* Sat Mar 12 2016 mpluskal@suse.com
- Update to 16d
  * Source code re-indented.
  * Fixes for Welcome screen on Mainframe
  * Fixed for Curses handling when collecting data to file - big
    bug for main frame and x86.
- Changes for 16b
  * Fixes for Welcome screen on Mainframe
  * Fixed for Curses handling when collecting data to file - big
    bug for main frame and x86.
- Changes for 16a
  * Nvidia GPU support - online & saved to file
    + You need a S822LC With NVIDIA GPU(s) and Nvidia Library
    installed libnvidia-ml.so
  * CPU Wide View - online view for up to 192 CPUs
  * CPU MHz per Core ratings for machine that allow cores with
    different MHz - online & saved to file
  * lscpu stats capture - online & to file
  * Z experiment mode showing CPU interrupts - Renamed U stats in
    version 16b - online only
  * Online colourising stats to aid usability - online only
  * Massive improvement in help information: nmon -? and nmon -h
  * Code change to alphabetic order for getopt() and key input
    functions - just code clean up
  * New nmon logo on flash screen - online only
  * Extra kernel stats - online only
- Drop nmon.1 and genereate manpage during build
* Sun Dec 13 2015 mpluskal@suse.com
- Update to 15h
  * No upstream changelog available
- Cleanup spec file
* Sun Aug  2 2015 mpluskal@suse.com
- Update to 15g
  * No upstream changelog available
* Fri Mar  6 2015 p.drouand@gmail.com
- Update to version 15a
  * Original PowerVM host environment supported
  * PowerKVM host environment supported
  /proc/ppc64/lparcfg is missing and SMT is switched off even
    is guests have it one
  * PowerKVM guest environment supported
  /proc/ppc64/lparcfg - probably mostly missing (1.9)
  * Native guest environment supported - not virtualised
  * Support Big and Little Endian - for POWER machines that can run both
- Do not re-tar the source file; not really useful
- Use download Url as source
* Tue Oct 28 2014 mpluskal@suse.com
- Add manpage
- Add licence file
- Minor spec file cleanup
* Fri Oct  4 2013 malcolmlewis@opensuse.org
- Updated to version 14i:
  + 2nd attempt at fixing my NFS stats bug - thanks to helpful
    users.
  + Dynamic memory handling for massive /proc/cpuinfo file & so
    much duplication & Tabs chars plus many formats on x86.
  + POWER has new LPAR details on the CPU stats online,
    Entitlement, Physical CPU used, Capped, SMT level, virtual
    Processors and Dotted lines on each primary thread helps you
    "see" the physical CPUs, plus file output saves the above,
    lparstat -i, ppc64_cpu & lsslot, ls-veth/vdev/vscsi, lscfg &
    bootlist commands output, saves SMT on the LPAR tab last
    column.
  + Start up flash panel has X86 or POWER CPU details. Note: some
    x86 Virtual Machines report CPU type QEMU or Virtual CPU but
    many don't.
  + Add -D X86 in the makefile to get the new features.
- Updates from version 14h:
  + This included a fix for POWER based machines when the
    Entitlement CPU is set below 10%% of a CPU - only applies to
    the POWER7+ processors or POWER7 that has a firmware upgrade
    like Power 770/780/79 and a fix for a crash if you gather NFS
    serving stats on certain Linux distributions & versions.
* Tue Jun  7 2011 pascal.bleser@opensuse.org
- initial version (14g)
